@@ -60,9 +60,9 @@ namespace Breeze
     //____________________________________________________________________
     void Helper::loadConfig()
     {
-        _viewFocusBrush = KStatefulBrush( KColorScheme::View, KColorScheme::FocusColor, _config );
-        _viewHoverBrush = KStatefulBrush( KColorScheme::View, KColorScheme::HoverColor, _config );
-        _viewNegativeTextBrush = KStatefulBrush( KColorScheme::View, KColorScheme::NegativeText, _config );
+        _viewFocusBrush = KStatefulBrush( KColorScheme::View, KColorScheme::FocusColor );
+        _viewHoverBrush = KStatefulBrush( KColorScheme::View, KColorScheme::HoverColor );
+        _viewNegativeTextBrush = KStatefulBrush( KColorScheme::View, KColorScheme::NegativeText );
 
         const QPalette palette( QApplication::palette() );
         const KConfigGroup group( _config->group( "WM" ) );
@@ -534,7 +534,7 @@ namespace Breeze
         if( !outline.isValid() ) return;
 
         // adjust rect
-        QRectF frameRect( rect.adjusted( 1, 1, -1, -1 ) );
+        QRectF frameRect( rect );
         frameRect.adjust( 0.5, 0.5, -0.5, -0.5 );
 
         // setup painter
@@ -546,22 +546,18 @@ namespace Breeze
         {
             default:
             case SideLeft:
-            frameRect.adjust( 0, 1, 0, -1 );
             painter->drawLine( frameRect.topRight(), frameRect.bottomRight() );
             break;
 
             case SideTop:
-            frameRect.adjust( 1, 0, -1, 0 );
             painter->drawLine( frameRect.topLeft(), frameRect.topRight() );
             break;
 
             case SideRight:
-            frameRect.adjust( 0, 1, 0, -1 );
             painter->drawLine( frameRect.topLeft(), frameRect.bottomLeft() );
             break;
 
             case SideBottom:
-            frameRect.adjust( 1, 0, -1, 0 );
             painter->drawLine( frameRect.bottomLeft(), frameRect.bottomRight() );
             break;
 
@@ -1056,7 +1052,8 @@ namespace Breeze
     //______________________________________________________________________________
     void Helper::renderDialGroove(
         QPainter* painter, const QRect& rect,
-        const QColor& color ) const
+        const QColor& color,
+        qreal first, qreal last ) const
     {
 
         // setup painter
@@ -1070,9 +1067,19 @@ namespace Breeze
             const qreal penWidth( Metrics::Slider_GrooveThickness );
             const QRectF grooveRect( rect.adjusted( penWidth/2, penWidth/2, -penWidth/2, -penWidth/2 ) );
 
-            painter->setPen( QPen( color, penWidth ) );
-            painter->setBrush( Qt::NoBrush );
-            painter->drawEllipse( grooveRect );
+            // setup angles
+            const int angleStart( first * 180 * 16 / M_PI );
+            const int angleSpan( (last - first ) * 180 * 16 / M_PI );
+            
+            // setup pen
+            if( angleSpan != 0 )
+            {
+                QPen pen( color, penWidth );
+                pen.setCapStyle( Qt::RoundCap );
+                painter->setPen( pen );
+                painter->setBrush( Qt::NoBrush );
+                painter->drawArc( grooveRect, angleStart, angleSpan );
+            }
         }
 
         
